@@ -767,7 +767,7 @@ class TestHandlers(BaseSessionTest):
         request = AWSRequest()
         url = 'https://machinelearning.us-east-1.amazonaws.com'
         new_endpoint = 'https://my-custom-endpoint.amazonaws.com'
-        data = '{"PredictEndpoint":"%s"}' % new_endpoint
+        data = f'{{"PredictEndpoint":"{new_endpoint}"}}'
         request.data = data.encode('utf-8')
         request.url = url
         handlers.switch_host_with_param(request, 'PredictEndpoint')
@@ -822,7 +822,7 @@ class TestHandlers(BaseSessionTest):
             arn = 'arn:aws:s3:us-west-2:123456789012:accesspoint:endpoint'
             handlers.validate_bucket_name({'Bucket': arn})
         except ParamValidationError:
-            self.fail('The s3 arn: %s should pass validation' % arn)
+            self.fail(f'The s3 arn: {arn} should pass validation')
 
     def test_validation_is_s3_outpost_arn(self):
         try:
@@ -832,7 +832,7 @@ class TestHandlers(BaseSessionTest):
             )
             handlers.validate_bucket_name({'Bucket': arn})
         except ParamValidationError:
-            self.fail('The s3 arn: %s should pass validation' % arn)
+            self.fail(f'The s3 arn: {arn} should pass validation')
 
     def test_validation_is_global_s3_bucket_arn(self):
         with self.assertRaises(ParamValidationError):
@@ -1213,7 +1213,7 @@ class TestSSEMD5(BaseMD5Test):
             'UploadPartCopy',
             'SelectObjectContent',
         ):
-            event = 'before-parameter-build.s3.%s' % op
+            event = f'before-parameter-build.s3.{op}'
             params = {
                 'SSECustomerKey': b'bar',
                 'SSECustomerAlgorithm': 'AES256',
@@ -1235,7 +1235,7 @@ class TestSSEMD5(BaseMD5Test):
 
     def test_copy_source_sse_params(self):
         for op in ['CopyObject', 'UploadPartCopy']:
-            event = 'before-parameter-build.s3.%s' % op
+            event = f'before-parameter-build.s3.{op}'
             params = {
                 'CopySourceSSECustomerKey': b'bar',
                 'CopySourceSSECustomerAlgorithm': 'AES256',
@@ -1619,10 +1619,10 @@ class TestPrependToHost(unittest.TestCase):
         (
             {
                 'AWS_LAMBDA_FUNCTION_NAME': 'foo',
-                '_X_AMZN_TRACE_ID': 'test123-=;:+&[]{}\"\'',
+                '_X_AMZN_TRACE_ID': 'test123-=;:+&[]{}"\'',
             },
             {},
-            {'X-Amzn-Trace-Id': 'test123-=;:+&[]{}\"\''},
+            {'X-Amzn-Trace-Id': 'test123-=;:+&[]{}"\''},
         ),
     ],
 )
